coll = {}

function coll.load()
	coll.player_cd = 0
	-- The grid cell size can be specified via the initialize method
	-- By default, the cell size is 32
	bump.initialize(32)

	-- now load all the map and player stuff
	player.name = "player"
	player.l, player.t, player.w, player.h = 0, 0, 32, 32

	bump.add(player)

	-- static objects from collision layer
	-- for i, z in ipairs(objects) do
	-- 	if z.oType == "bot" then
	-- 		bump.add(z)
	-- 	end
	-- end
	
	-- static objects from collision layer


	for i, v in pairs(map.level("Collision").objects) do
		bump.addStatic({
			name = v.name,
			l = v.x,
			t = v.y,
			w = v.width,
			h = v.height
		})
	end
	map.level("Collision").visible = false
	
	-- objects from objects layer
	for i, v in pairs(map.level("Objects").objects) do
		if v.name == "end" then		-- portal to another level
			bump.addStatic({
				name = v.name,
				l = v.x,
				t = v.y,
				w = v.width,
				h = v.height
			})
		end
	end
	map.level("Objects").visible = false
end

function coll.update(dt)
	-- update player hit box cooldown
	if coll.player_cd > 0 then
		coll.player_cd = coll.player_cd - dt*10
	end

	-- first update player coordinates for bump
	player.l = player.x
	player.t = player.y
	player.w = 32
	player.h = 32


	-- for i, z in ipairs(objects) do
	-- 	if z.oType == "bot" then
	-- 		watcher.store(16, z.name, " has been iterated")
	-- 		z.l = z.currPosX
	-- 		z.t = z.currPosY
	-- 		watcher.watch(20, z.l)
	-- 		z.w = 32
	-- 		z.h = 32
	-- 	end
	-- end
	bump.collide()
end

-- bump has 4 callbacks:
-- * collision is called every time a collision occurs
-- * endCollision is called every time a collision ends
-- * getBBox must accept an item and return its bounding box: left, top, width and height
-- * shouldCollide is used to skip collisions
-- None of the callbacks is mandatory.
-- collision and stopCollision do nothing by default.
-- getBBox calls item:getBBox() by default

function bump.collision(item1, item2, dx, dy)

	if item1.name == "player" then
		--watcher.watch(2, item1.name.." collides with "..item2.name.." displacement vector   "..dx.."   "..dy)
		player.x, player.y = player.x + dx, player.y + dy
		tx, ty = tx - dx, ty - dy

		-- check if end point
		if item2.name == "end" then
			if map.name == map_count then
				game_state = "won"
				audio.play(9, false, 1)	-- another map sound
			else
				map.name = map.name + 1
				map.load(map.name)
				audio.play(8, false, 1)	-- another map sound
			end
		end

		-- check collision with bots (a bad thing!)
		if item2.type == "bot" and coll.player_cd <= 0 then
			playerHP = playerHP - 1
			coll.player_cd = 20
			audio.play(17, false, 1)
		end
	end

	if item2.name == "player" then
		if item1.type == "bot" and coll.player_cd <= 0 then
			playerHP = playerHP - 1
			coll.player_cd = 20
			audio.play(17, false, 1)
		end
	end

	if item1.name == "bullet" then
			bump.remove(item1)
			bullets.removeBullet(item1)
			audio.play(11, false, 0.8)		-- play bullet col sound
			if item2.type == "bot" then
				-- checking bot types
				if item2.type == "sa" then
					audio.play(13, false, 0.8)
				elseif item2.type == "sd" then
					audio.play(14, false, 0.8)
				else
					audio.play(15, false, 0.8)
				end
				bump.remove(item2)
				zergs.removeZerg(item2)
			end
	end

	if item2.name == "bullet" then
			bump.remove(item2)
			bullets.removeBullet(item2)
			audio.play(11, false, 0.8)		-- play bullet col sound
			if item1.type == "bot" then
				-- checking bot types
				if item1.type == "sa" then
					audio.play(13, false, 0.8)
				elseif item1.type == "sd" then
					audio.play(14, false, 0.8)
				else
					audio.play(15, false, 0.8)
				end
				bump.remove(item1)
				zergs.removeZerg(item1)
			end
	end

	if item1.type == "bot"  then
		item1.l = item1.l + dx
		item1.t = item1.t + dy
		item1.dir = math.random(1, 4)
		--watcher.watch(3, item1.name)
	end

	if item2.type == "bot"  then
		item2.l = item2.l - dx
		item2.t = item2.t - dy
		item1.dir = math.random(1, 4)
		--watcher.watch(3, item2.name)
	end

	-- if item1.name == "player" and item2.type == "trap" then
	-- 	watcher.watch(3, item1.name.." collides with "..item2.type.." displacement vector   "..dx.."   "..dy)
	-- 	playerHP = playerHP - 1
	-- end
	-- if item2.name == "player" and item1.type == "trap" then
	-- 	watcher.watch(4, item1.name.." collides with "..item2.type.." displacement vector   "..dx.."   "..dy)
	-- 	playerHP = playerHP - 1
	-- end

	--bullet of player hit bots
	-- if item1.name == "bullet"  and item2.oType == "bot" then
	-- 		bump.remove(item1)\	
	-- 		bullets.removeBullet(item1)
	-- 		item2.HP = item2.HP - 1
	-- end
end

function bump.endCollision(item1, item2)
	--print(item1.name, "stopped colliding with", item2.name)
end

function bump.getBBox(item)
  return item.l, item.t, item.w, item.h
end

function bump.shouldCollide(item1, item2)
  if item1.name == "bullet" and item2.name == "player" or
  	 item2.name == "bullet" and item1.name == "player" then
  		return false
  else
  		return true -- we could add certain conditions here - for example, make objects of the same group not collide
  end
end

function coll.draw()

end