-- requires
ATL 			= require("lib/AdvTiledLoader")	-- advanced tiled loader
anim8 			= require("lib/anim8/anim8")	-- animation library
jumper 			= require("lib/Jumper")			-- shortest path library
bump 			= require("lib/bump/bump")		-- simple collision library
require("helpers")								-- some helper functions and constants
require("lib/watcher")							-- console for debugging
require("lib/vector")							-- vector library
require("lib/TEsound")							-- audio library
require("conf")									-- configuration
require("audio")								-- sounds and bgm
require("map")									-- map
require("player")								-- player stuff
require("bullets")								-- bullets stuff
require("gui")									-- gui
--require("obj")									-- objects
--require("AI")									-- AI & BOTS
require("light")								-- light
require("collisions")							-- collisions
require("controls")								-- obviously, controls
--require("botBalance")							-- bot balance
require("zergs")								-- bots v2
require("traps")								-- traps v1

img = "assets/images/"
snd	= "assets/sounds/"

game_state = "menu"								-- "playing", "menu", "over", "pause", "won"
map_count = 3 									-- all map count xD
boxes = false									-- bounded boxes

function love.load()
	-- sounds load
	audio.load()

	-- menu
	menu.load()

	-- watcher load
	watcher.load(args)

	-- load first map
	--map.load(3)
	
	-- load bullets stuff
	bullets.load()

	-- load some control values
	controls.load()

	--gui start
	gui.load()

	-- play bgm (currently only one)
	audio.play(1, true, 0.2)

	frame = love.graphics.newImage(img.."frame.png")
end

function love.update(dt)
	watcher.watch(1, "nothing new here xD")
	controls.update(dt)
	if game_state ~= "pause" and game_state ~= "over" then

		-- update watcher coords
		watcher.update(dt)

		-- audio library stuff
		TEsound.cleanup()

		-- checking states
		if game_state == "menu" then
			menu.update(dt)
		else
			-- controls
			controls.update(dt)

			if game_state ~= "won" then
				-- map update
				map.update(dt)

				-- bullets update
				bullets.update(dt)	

				-- bots update
				zergs.update(dt)

				traps:update(dt)
			end

			-- controls

			-- audio library stuff
			TEsound.cleanup()

			-- AI update
			--AI:update(dt)

			-- gui update
			gui.update(dt)
		end
	end
end

function love.draw()
	if game_state == "menu" and game_state ~= "pause" then
		menu.draw()
	else
		-- Apply the translation (for map)
		love.graphics.translate(math.floor(tx), math.floor(ty))

		-- draw map
		map.draw()

		-- static objects draw
	--objects:draw()

		-- coll draw for debugging
		-- coll.draw()
		
		-- AI draw
	--AI:draw()

		-- undo the translation
		love.graphics.translate(-math.floor(tx), -math.floor(ty))

		traps:draw()
		-- bots draw
		zergs.draw()

		-- player draw (after un-translation)
		player.draw()

		-- draw bullets
		bullets.draw()

		-- draw light if needed
		light.draw()

		love.graphics.draw(frame, 0, 0)

		-- gui draw
		gui.draw()

		-- draw watcher
		watcher.draw()
	end
end

-- when game quits
function love.quit()
	-- stop bgm before quiting, to cleanup
	audio.stop(1)
	love.event.quit()
end